/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2010-2013 Richard Hughes <richard@hughsie.com>
 *
 * Licensed under the GNU Lesser General Public License Version 2.1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifndef __CD_TEST_SHARED_H
#define __CD_TEST_SHARED_H

#include <glib-object.h>

G_BEGIN_DECLS

gchar		*cd_test_get_filename		(const gchar	*filename);
void		 cd_test_loop_quit		(void);
void		 cd_test_loop_run_with_timeout	(guint		 timeout_ms);
gboolean	 cd_test_compare_lines		(const gchar	*txt1,
						 const gchar	*txt2,
						 GError		**error);

G_END_DECLS

#endif /* __CD_TEST_SHARED_H */

